/**
 * @license
 * Copyright 2022 Google LLC
 * SPDX-License-Identifier: Apache-2.0
 */
import * as jsonParser from 'jsonc-parser';
import { parseTree as parseTreeInternal } from 'jsonc-parser';
import { WireitError } from '../error.js';
export function findNamedNodeAtLocation(astNode, path, script, file) {
    const node = findNodeAtLocation(astNode, path);
    const parent = node?.parent;
    if (node === undefined || parent === undefined) {
        return undefined;
    }
    const name = parent.children?.[0];
    if (parent.type !== 'property' || name == null) {
        throw new WireitError({
            type: 'failure',
            reason: 'invalid-config-syntax',
            script,
            diagnostic: {
                severity: 'error',
                message: `Expected a property, but got a ${parent.type}`,
                location: {
                    file,
                    range: { offset: astNode.offset, length: astNode.length },
                },
            },
        });
    }
    node.name = name;
    return node;
}
export function findNodeAtLocation(astNode, path) {
    return jsonParser.findNodeAtLocation(astNode, path);
}
export function parseTree(json, placeholder) {
    const errors = [];
    const result = parseTreeInternal(json, errors);
    if (errors.length > 0) {
        throw new WireitError({
            type: 'failure',
            reason: 'invalid-json-syntax',
            errors,
            script: placeholder,
        });
    }
    return result;
}
//# sourceMappingURL=ast.js.map